@@ -2468,6 +2468,12 @@ get_unique_id (LPDISPATCH mail, int create, const char *uuid)
   if (!create)
     {
       char *uid = get_pa_string (mail, GPGOL_UID_DASL);
+      if (!uid)
+        {
+          log_debug ("%s:%s: No uuid found in oom for '%p' looking for PR_INTERNET_MESSAGE_ID_W_DASL",
+                     SRCNAME, __func__, mail);
+          uid = get_pa_string(mail, PR_INTERNET_MESSAGE_ID_W_DASL);
+        }
       if (!uid)
         {
           log_debug ("%s:%s: No uuid found in oom for '%p'",
@@ -2531,7 +2537,7 @@ get_unique_id_s (LPDISPATCH mail, int create, const char *uuid)
     {
       return val;
     }
-  return std::string (val);
+  return std::string ();
 }
 
 HWND
